## 0.4.0 (2017-03-27)
- Add aloisius.stacks to allow iterating the stacks

## 0.3.1 (2017-02-26)
- Make FutureOutputs inherit from collections.Mapping

## 0.3 (2015-06-30)
- Publish aloisius to PyPI

## 0.2.1 (2015-06-29)
- Increase parallelism by using FutureOutputs

## 0.2 (2015-06-28)
- Add support for parallel stack operations

## 0.1 (2015-06-27)
- First release
